@@ -30,7 +30,7 @@ class DetectorAnalyzeResult:
     reference_image_file_ids: list[str]
     detector_requests: list[dict[str, str | float | bool | int]]
     detector_results: list[dict[str, str | float | bool | int | list]]
-    comparison_settings: dict[str, str | float | list]
+    comparison_settings: dict[str, str | float | list | dict]
     comparison_results: list[float]
     result: float
     analyzed_at: float
